==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/SyslogLoggingDestinationParametersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SyslogLoggingDestinationParametersFluent<A extends io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAddress();
  public A withAddress(java.lang.String address);
  public java.lang.Boolean hasAddress();
  
  /**
   * Method is deprecated. use withAddress instead.
   */
  @java.lang.Deprecated
  public A withNewAddress(java.lang.String arg0);
  public java.lang.String getFacility();
  public A withFacility(java.lang.String facility);
  public java.lang.Boolean hasFacility();
  
  /**
   * Method is deprecated. use withFacility instead.
   */
  @java.lang.Deprecated
  public A withNewFacility(java.lang.String arg0);
  public java.lang.Integer getPort();
  public A withPort(java.lang.Integer port);
  public java.lang.Boolean hasPort();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/SyslogLoggingDestinationParametersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SyslogLoggingDestinationParametersFluent<A extends io.fabric8.openshift.api.model.operator.v1.SyslogLoggingDestinationParametersFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getAddress();
  public A withAddress(java.lang.String address);
  public java.lang.Boolean hasAddress();
  
  /**
   * Method is deprecated. use withAddress instead.
   */
  @java.lang.Deprecated
  public A withNewAddress(java.lang.String arg0);
  public java.lang.String getFacility();
  public A withFacility(java.lang.String facility);
  public java.lang.Boolean hasFacility();
  
  /**
   * Method is deprecated. use withFacility instead.
   */
  @java.lang.Deprecated
  public A withNewFacility(java.lang.String arg0);
  public java.lang.Integer getMaxLength();
  public A withMaxLength(java.lang.Integer maxLength);
  public java.lang.Boolean hasMaxLength();
  public java.lang.Integer getPort();
  public A withPort(java.lang.Integer port);
  public java.lang.Boolean hasPort();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
